@@ -2,30 +2,25 @@
 #
 #   file: lib/Dist/Zilla/Tester/DieHard.pm
 #
-
-#pod =encoding UTF-8
-#pod
-#pod =head1 COPYRIGHT AND LICENSE
-#pod
-#pod Copyright © 2015 Van de Bugger
-#pod
-#pod This file is part of perl-Dist-Zilla-Tester-DieHard.
-#pod
-#pod perl-Dist-Zilla-Tester-DieHard is free software: you can redistribute it and/or modify it under
-#pod the terms of the GNU General Public License as published by the Free Software Foundation,
-#pod either version 3 of the License, or (at your option) any later version.
-#pod
-#pod perl-Dist-Zilla-Tester-DieHard is distributed in the hope that it will be useful, but WITHOUT
-#pod ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-#pod PURPOSE. See the GNU General Public License for more details.
-#pod
-#pod You should have received a copy of the GNU General Public License along with
-#pod perl-Dist-Zilla-Tester-DieHard. If not, see <http://www.gnu.org/licenses/>.
-#pod
-#pod =cut
-
+#   Copyright © 2015 Van de Bugger
+#
+#   This file is part of perl-Dist-Zilla-Tester-DieHard.
+#
+#   perl-Dist-Zilla-Tester-DieHard is free software: you can redistribute it and/or modify it under
+#   the terms of the GNU General Public License as published by the Free Software Foundation,
+#   either version 3 of the License, or (at your option) any later version.
+#
+#   perl-Dist-Zilla-Tester-DieHard is distributed in the hope that it will be useful, but WITHOUT
+#   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+#   PURPOSE. See the GNU General Public License for more details.
+#
+#   You should have received a copy of the GNU General Public License along with
+#   perl-Dist-Zilla-Tester-DieHard. If not, see <http://www.gnu.org/licenses/>.
+#
 #   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
+#pod =for test_synopsis my ( %args, $expected_exception, $expected_messages );
+#pod
 #pod =head1 SYNOPSIS
 #pod
 #pod Use C<Dist::Zilla::Tester::DieHard> instead of C<Dist::Zilla::Tester>:
@@ -35,7 +30,7 @@
 #pod     use Test::Fatal;
 #pod     use Test::More;
 #pod
-#pod     my $tzil = Builder->from_config( … );
+#pod     my $tzil = Builder->from_config( \%args );
 #pod     my $ex = exception { $tzil->build(); };
 #pod     is( $ex, $expected_exception, 'check status' );
 #pod     cmd_deeply( $tzil->log_messages, $expected_messages, 'check log messages' );
@@ -78,7 +73,7 @@ package Dist::Zilla::Tester::DieHard;
 use Moose;
 
 # ABSTRACT: Die hard Dist::Zilla, but save the messages
-our $VERSION = 'v0.4.0'; # VERSION
+our $VERSION = 'v0.4.1'; # VERSION
 our $CLASS = __PACKAGE__;
 
 extends 'Dist::Zilla::Tester';
@@ -113,7 +108,7 @@ use Moose;
 use namespace::autoclean;
 
 ## no critic ( ProhibitReusedNames )
-our $VERSION = 'v0.4.0'; # VERSION
+our $VERSION = 'v0.4.1'; # VERSION
 our $CLASS = __PACKAGE__;
 ## critic ( ProhibitReusedNames )
 
@@ -185,7 +180,7 @@ use Moose;
 use namespace::autoclean;
 
 ## no critic ( ProhibitReusedNames )
-our $VERSION = 'v0.4.0'; # VERSION
+our $VERSION = 'v0.4.1'; # VERSION
 ## critic ( ProhibitReusedNames )
 
 has exception => (              # Survivor stores the exception killed the buider
@@ -221,6 +216,19 @@ __PACKAGE__->meta->make_immutable;
 
 # --------------------------------------------------------------------------------------------------
 
+#pod =head1 COPYRIGHT AND LICENSE
+#pod
+#pod Copyright (C) 2015 Van de Bugger
+#pod
+#pod License GPLv3+: The GNU General Public License version 3 or later
+#pod <http://www.gnu.org/licenses/gpl-3.0.txt>.
+#pod
+#pod This is free software: you are free to change and redistribute it. There is
+#pod NO WARRANTY, to the extent permitted by law.
+#pod
+#pod
+#pod =cut
+
 # doc/what.pod #
 
 #pod =encoding UTF-8
@@ -302,7 +310,7 @@ Dist::Zilla::Tester::DieHard - Die hard Dist::Zilla, but save the messages
 
 =head1 VERSION
 
-Version v0.4.0, released on 2015-09-17 16:57 UTC.
+Version v0.4.1, released on 2015-10-22 14:52 UTC.
 
 =head1 WHAT?
 
@@ -319,7 +327,7 @@ Use C<Dist::Zilla::Tester::DieHard> instead of C<Dist::Zilla::Tester>:
     use Test::Fatal;
     use Test::More;
 
-    my $tzil = Builder->from_config( … );
+    my $tzil = Builder->from_config( \%args );
     my $ex = exception { $tzil->build(); };
     is( $ex, $expected_exception, 'check status' );
     cmd_deeply( $tzil->log_messages, $expected_messages, 'check log messages' );
@@ -389,6 +397,8 @@ Using C<Dist::Zilla::Tester::DieHard> instead of regular C<Dist::Zilla::Tester>
 problem: even if a plugin throws an exception in constructor, C<< Builder->from_config >> does not
 die but returns a "survivor" object which can be used to retrieve log messages.
 
+=for test_synopsis my ( %args, $expected_exception, $expected_messages );
+
 =head1 NOTES
 
 Regular C<Dist::Zilla::Tester> (as of v5.039) is not documented, so and I have to study its sources
@@ -406,19 +416,12 @@ Van de Bugger <van.de.bugger@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2015 Van de Bugger
+Copyright (C) 2015 Van de Bugger
 
-This file is part of perl-Dist-Zilla-Tester-DieHard.
+License GPLv3+: The GNU General Public License version 3 or later
+<http://www.gnu.org/licenses/gpl-3.0.txt>.
 
-perl-Dist-Zilla-Tester-DieHard is free software: you can redistribute it and/or modify it under
-the terms of the GNU General Public License as published by the Free Software Foundation,
-either version 3 of the License, or (at your option) any later version.
-
-perl-Dist-Zilla-Tester-DieHard is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE. See the GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License along with
-perl-Dist-Zilla-Tester-DieHard. If not, see <http://www.gnu.org/licenses/>.
+This is free software: you are free to change and redistribute it. There is
+NO WARRANTY, to the extent permitted by law.
 
 =cut
